# Contributors

* Florian Lemmerich (flemmerich) [florian@lemmerich.net](mailto:florian@lemmerich.net)
* Martin Becker (mgbckr) [mgbckr@informatik.uni-rostock.de](mailto:mgbckr@informatik.uni-rostock.de)
* Felix Stamm (Feelx234)
